##################
#
# Relational Data on Members of Portuguese Governments (1976-2014)
# Nuno Moniz and Adriano Campos
# Data 2015 (MDPI)
#
##################
#
# INFO
# 
# This file contains code on how to load the dataset in R and 
# some basic procedures to explore the available relational data.
#
# N.a. = Not Available/Unknown
# N.d. = No date found
#
##################
#
# VARIABLES
#
# Name (string): name of the member of government
# Party (string): political party/group [AD, CDS, Independent, PPM, PRD, PS, PSD]
# RepParty (string): ("elected in representation of the") political party/coalition [AD, Alfacinha Movement, ASDI, CDS, Central Block, Independent, PCP, PPM, PRD, Presidential Initiative, PS, PS/CDS, PSD, PSD/CDS, UDP, UEDS]
# Begin (numeric): year that a connection starts. -1 means no date or that it was not possible to obtain the exact date
# End (numeric): year that a connection ends. -1 means no date or that it was not possible to obtain the exact date
# N_Years (numeric): number of years between the begin and end year. -1 means not available and is applied when one of the two previous variables or both are unknown
# Organization (string): name of the organization [in portuguese]
# Position (string): position in the organization. CA, CF and AG translates as Board of Directors, Fiscal Council and General Assembly [in portuguese]
# Econ_Sector (numeric): connection to a given economic sector [0-7]. details in the paper <metadata applied to a given data entry>
# ThreeMore_Econ_Sector (numeric): flag [0,1] to indicate that a given person has connections to three or more economic sectors <metadata applied to all data entries of a given person>
# Course_University (string): course attended/completed. "N.a." translates as not available. "?" means that there was no specific information found on the course. <metadata applied to a given data entry>
# Place_University (string): city of the university. "N.a." translates as not available. "?" means that there was no specific information found on the city. <metadata applied to a given data entry>
# Privatized_Company (numeric): flag [0,1] to indicate that a given connection involves a privatized company. <metadata applied to a given data entry>
# Gender (string): gender of the person ["M","F"]. <metadata applied to all data entries of a given person>
# MajorEconGroup (string): connection to a given major economic group. details in the paper <metadata applied to a given data entry>
# PPP (numeric): flag [0,1] to indicate that a given connection involves a company involved in public-private partnerships. <metadata applied to a given data entry>
# Angola (numeric): flag [0,1] to indicate that a given connection involves a company with capital from Angola. <metadata applied to a given data entry>
# PSI20 (string): connection to a company indexed in the Portuguese Stock Market Index. details in the paper <metadata applied to a given data entry>
# Government (numeric): connection to a given government [0,1,2,3,...,19] where 0 means that it is not a government connection. <metadata applied to a given data entry>
# BusinessConnected (numeric) : flag [0,1] to indicate if a given person is connected to businesses <metadata applied to all data entries of a given person>
#
##################
#
# AUX - WRITE NEW FILE
# write.csv(ptgov,file="PTGov_Dataset.csv")
#
##################

workingdirectory <- "" #INSERT THE WORKING DIRECTORY

#Working Directory
setwd(workingdirectory)

#Load Data
ptgov <- read.csv("PTGov_Dataset.csv")
ptgov$X <- NULL

ptgov$Name <- as.character(ptgov$Name)
ptgov$Party <- as.character(ptgov$Party)
ptgov$RepParty <- as.character(ptgov$RepParty)
ptgov$Begin <- as.numeric(ptgov$Begin)
ptgov$End <- as.numeric(ptgov$End)
ptgov$N_Years <- as.numeric(ptgov$N_Years)
ptgov$Organization <- as.character(ptgov$Organization)
ptgov$Position <- as.character(ptgov$Position)
ptgov$Econ_Sector <- as.numeric(ptgov$Econ_Sector)
ptgov$ThreeMore_Econ_Sector <- as.numeric(ptgov$ThreeMore_Econ_Sector)
ptgov$Course_University <- as.character(ptgov$Course_University)
ptgov$Place_University <- as.character(ptgov$Place_University)
ptgov$Privatized_Company <- as.numeric(ptgov$Privatized_Company)
ptgov$Gender <- as.character(ptgov$Gender)
ptgov$MajorEconGroup <- as.character(ptgov$MajorEconGroup)
ptgov$PPP <- as.numeric(ptgov$PPP)
ptgov$Angola <- as.numeric(ptgov$Angola)
ptgov$PSI20 <- as.character(ptgov$PSI20)
ptgov$Government <- as.numeric(ptgov$Government)
ptgov$BusinessConnected <- as.numeric(ptgov$BusinessConnected)

##############################
#GENERAL
##############################

#Number of members per party
table(unique(ptgov[,1:2])$Party)

#Number of people connected and not connected to businesses (FLAG 0/1)
table(unique(ptgov[,c("Name","BusinessConnected")])$BusinessConnected)

##############################
#ECONOMIC SECTORS
##############################

#Number of people connector to economic sectors
length(unique(ptgov[ptgov$Econ_Sector>0,]$Name))

#Number of people in each party per economic sector
table(unique(unique(ptgov[ptgov$Econ_Sector>0,])[,c("Name","Party"),])$Party)

#Number of connections per economic sector
table(ptgov$Econ_Sector)

#Number of people connected to three or more economic sectors
length(unique(ptgov[ptgov$ThreeMore_Econ_Sector>0,]$Name))

#Number of people per party connected to three or more economic sectors
table(unique(unique(ptgov[ptgov$ThreeMore_Econ_Sector>0,])[,c("Name","Party"),])$Party)

##############################
#EDUCATION
##############################

#Number of graduations per course (? = we have information on this connection but cannot precise the course)
table(ptgov[ptgov$Course_University!="N.a.",]$Course_University)

#Number of people per course (? = we have information on this connection but cannot precise the course)
table(unique(ptgov[ptgov$Course_University!="N.a.",][,c("Name","Course_University")])$Course_University)

#Number of graduations per city (? = we have information on this connection but cannot precise the city)
table(ptgov[ptgov$Place_University!="N.a.",]$Place_University)

#Number of people graduated per city (? = we have information on this connection but cannot precise the course)
table(unique(ptgov[ptgov$Place_University!="N.a.",][,c("Name","Place_University")])$Place_University)

##############################
#PRIVATIZED COMPANIES
##############################

#Number of connection per party to privatized companies
table(ptgov[ptgov$Privatized_Company==1,]$Party)

#Number of people per party connected to privatized companies
table(unique(ptgov[ptgov$Privatized_Company==1,][,c("Name","Party")])$Party)

#Intensity (connections/people)
table(ptgov[ptgov$Privatized_Company==1,]$Party)/table(unique(ptgov[ptgov$Privatized_Company==1,][,c("Name","Party")])$Party)

##############################
#GENDER
##############################

#Number of people by gender
table(unique(ptgov[,c("Name","Gender")])$Gender)

##############################
#MAJOR ECONOMIC GROUPS (Amorim, BCP, BES, BPI, CGD, Champalimaud, Champalimaud/Santader (transition period), Jerónimo Martins, Mello, Mota-Engil, PT, Santander, Sonae)
##############################

#Number of connections per major economic groups
table(ptgov$MajorEconGroup)

#Number of connection to major economic groups per party
table(ptgov[ptgov$MajorEconGroup!="No",]$Party)

#Number of people connected to major economic groups per party
table(unique(ptgov[ptgov$MajorEconGroup!="No",c("Name","Party")])$Party)

#Intensity (connections/people)
table(ptgov[ptgov$MajorEconGroup!="No",]$Party)/table(unique(ptgov[ptgov$MajorEconGroup!="No",c("Name","Party")])$Party)

##############################
#PUBLIC-PRIVATE PARTNERSHIPS (PPP's)
#Companies connected to PPP's
##############################

#Number of connection per party to privatized companies
table(ptgov[ptgov$PPP==1,]$Party)

#Number of people per party connected to privatized companies
table(unique(ptgov[ptgov$PPP==1,][,c("Name","Party")])$Party)

#Intensity (connections/people)
table(ptgov[ptgov$PPP==1,]$Party)/table(unique(ptgov[ptgov$PPP==1,][,c("Name","Party")])$Party)

##############################
#ANGOLA
#Companies connected to capital from Angola
##############################

#Number of connection per party to privatized companies
table(ptgov[ptgov$Angola==1,]$Party)

#Number of people per party connected to privatized companies
table(unique(ptgov[ptgov$Angola==1,][,c("Name","Party")])$Party)

#Intensity (connections/people)
table(ptgov[ptgov$Angola==1,]$Party)/table(unique(ptgov[ptgov$Angola==1,][,c("Name","Party")])$Party)

##############################
#PSI20 - PORTUGUESE STOCK MARKET INDEX (BCP, BES, Banif, EDP, GALP, Jerónimo Martins, Mota-Engil, Portucel, PT, REN, Semapa, Sonae, ZON)
##############################

#Number of connections per indexed company
table(ptgov$PSI20)

#Number of connection to indexed companies per party
table(ptgov[ptgov$PSI20!="No",]$Party)

#Number of people connected to indexed companies per party
table(unique(ptgov[ptgov$PSI20!="No",c("Name","Party")])$Party)

#Intensity (connections/people)
table(ptgov[ptgov$PSI20!="No",]$Party)/table(unique(ptgov[ptgov$PSI20!="No",c("Name","Party")])$Party)

##############################
#GOVERNMENT
##############################

#Number of people per government
table(unique(ptgov[ptgov$Government!="No",c("Name","Government")])$Government)


